@@ -1,12 +1,10 @@
 package Pcore::Core::H;
 
-use Pcore qw[-export];
+use Pcore -export => {    #
+    DEFAULT => [qw[H]],
+};
 use Pcore::Core::H::Cache;
 
-our @EXPORT_OK   = qw[H];
-our %EXPORT_TAGS = ();
-our @EXPORT      = qw[H];
-
 sub H {
     state $H = Pcore::Core::H::Cache->new;
 
