@@ -1,7 +1,6 @@
 package Pcore::Util::Term::Progress::Indicator::Bar;
 
-use Pcore -class;
-use Term::ANSIColor qw[:constants];
+use Pcore -class, -ansi;
 
 with qw[Pcore::Util::Term::Progress::Indicator];
 
@@ -148,13 +147,13 @@ sub _draw ($self) {
 ## -----SOURCE FILTER LOG BEGIN-----
 ##
 ## PerlCritic profile "pcore-script" policy violations:
-## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
-## │ Sev. │ Lines                │ Policy                                                                                                         │
-## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 12                   │ Subroutines::ProhibitExcessComplexity - Subroutine "_draw" with high complexity score (25)                     │
-## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 12                   │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_draw' declared but not used        │
-## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
+## | Sev. | Lines                | Policy                                                                                                         |
+## |======+======================+================================================================================================================|
+## |    3 | 11                   | Subroutines::ProhibitExcessComplexity - Subroutine "_draw" with high complexity score (25)                     |
+## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
+## |    3 | 11                   | Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_draw' declared but not used        |
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
 __END__
